@@ -157,7 +157,7 @@ class Foreperson:
                 "The experiment directory cannot be found.")
 
         self.reduction.input_files = [
-            self.directory_path + str(r) for r in run_numbers]
+            self.directory_path + str(r) + '.dat' for r in run_numbers]
 
 
     def setup(self, recipe):
